/**
 * This script turns the OS env var into Angular env file.
 *
 * Source: https://medium.com/@natchiketa/angular-cli-and-os-environment-variables-4cfa3b849659
 */
import { writeFile } from 'fs';
import { argv } from 'yargs';

// Would be passed to script like this:
// `ts-node set-env.ts --environment=dev`
// we get it from yargs's argv object
const environment = argv.environment;
const isProd = environment === 'prod';

const targetPath = `./src/environments/environment.${environment}.ts`;
const envConfigFile = `
export const environment = {
  production: ${isProd},
  mapServerUrl: '${process.env.MAPS_SERVER_URL}',
  arcgisServerUrl: '${process.env.ARCGIS_SERVICES_URL}',
  proxyUrl: '${process.env.PROXY_URL}',
  electron: '${process.env.ELECTRON}'
};
`;

writeFile(targetPath, envConfigFile, (err) => {
  if (err) {
    console.log(err);
  } else {
    console.log(`Output generated at ${targetPath}`);
  }
});
