import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { RouterModule, Routes } from '@angular/router';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { TranslateModule, TranslateLoader } from '@ngx-translate/core';
import { TranslateHttpLoader } from '@ngx-translate/http-loader';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import { BsDropdownModule } from 'ngx-bootstrap/dropdown';
import { TypeaheadModule } from 'ngx-bootstrap/typeahead';
import { TooltipModule } from 'ngx-bootstrap/tooltip';
import { ButtonsModule } from 'ngx-bootstrap/buttons';

import { AppComponent } from './app.component';
import { MapComponent } from './map/map.component';
import { EditorComponent } from './editor/editor.component';
import { ModalModule } from 'ngx-bootstrap/modal';
import { MainMenuComponent } from './editor/modals/main-menu/main-menu.component';
import { NavigationHelpComponent } from './editor/modals/navigation-help/navigation-help.component';
import { MapsMenuComponent } from './editor/modals/maps-menu/maps-menu.component';
import { MapScaleErrorComponent } from './editor/modals/map-scale-error/map-scale-error.component';
import { TopographyLoadingComponent } from './editor/modals/topography-loading/topography-loading.component';
import { TextureSelectorComponent } from './editor/modals/texture-selector/texture-selector.component';
import { EditionHelpComponent } from './editor/modals/edition-help/edition-help.component';
import { TouchpadComponent } from './touchpad/touchpad.component';
import { MarkerPromptComponent } from './map/drawing/marker-prompt/marker-prompt.component';


export function HttpLoaderFactory(http: HttpClient) {
  return new TranslateHttpLoader(http, './assets/i18n/', '.json');
}

const appRoutes: Routes = [
  { path: '', pathMatch: 'full', component: EditorComponent },
  { path: 'touchpad/:id', component: TouchpadComponent }
];

@NgModule({
  declarations: [
    AppComponent,
    MapComponent,
    EditorComponent,
    MainMenuComponent,
    NavigationHelpComponent,
    MapsMenuComponent,
    MapScaleErrorComponent,
    TopographyLoadingComponent,
    TextureSelectorComponent,
    EditionHelpComponent,
    TouchpadComponent,
    MarkerPromptComponent
  ],
  imports: [
    BrowserModule,
    FormsModule,
    HttpClientModule,
    RouterModule.forRoot(appRoutes),
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: HttpLoaderFactory,
        deps: [HttpClient]
      }
    }),
    FontAwesomeModule,
    BsDropdownModule.forRoot(),
    TypeaheadModule.forRoot(),
    TooltipModule.forRoot(),
    ButtonsModule.forRoot(),
    ModalModule.forRoot(),
  ],
  providers: [],
  bootstrap: [AppComponent],
  entryComponents: [MarkerPromptComponent]
})
export class AppModule { }
