import { async, ComponentFixture, TestBed } from '@angular/core/testing';
import { FormsModule } from '@angular/forms';
import { HttpClientTestingModule, HttpTestingController } from '@angular/common/http/testing';
import { RouterTestingModule } from '@angular/router/testing';
import { TranslateModule } from '@ngx-translate/core';
import { TypeaheadModule, TooltipModule, ModalModule } from 'ngx-bootstrap';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';

import { EditorComponent } from './editor.component';
import { MapComponent } from '../map/map.component';
import { MainMenuComponent } from './modals/main-menu/main-menu.component';
import { MapsMenuComponent } from './modals/maps-menu/maps-menu.component';
import { NavigationHelpComponent } from './modals/navigation-help/navigation-help.component';
import { EditionHelpComponent } from './modals/edition-help/edition-help.component';
import { MapScaleErrorComponent } from './modals/map-scale-error/map-scale-error.component';
import { TopographyLoadingComponent } from './modals/topography-loading/topography-loading.component';
import { TextureSelectorComponent } from './modals/texture-selector/texture-selector.component';
import { DrawingMode } from '../map/drawing/utils';

describe('EditorComponent', () => {
  let component: EditorComponent;
  let fixture: ComponentFixture<EditorComponent>;

  beforeEach(async(() => {
    TestBed.configureTestingModule({
      imports: [
        FormsModule,
        ModalModule.forRoot(),
        TypeaheadModule.forRoot(),
        TooltipModule.forRoot(),
        FontAwesomeModule,
        HttpClientTestingModule,
        RouterTestingModule,
        TranslateModule.forRoot()
      ],
      declarations: [
        EditorComponent,
        MapComponent,
        MainMenuComponent,
        MapsMenuComponent,
        NavigationHelpComponent,
        EditionHelpComponent,
        MapScaleErrorComponent,
        TopographyLoadingComponent,
        TextureSelectorComponent
      ]
    })
    .compileComponents();
  }));

  beforeEach(async () => {
    fixture = TestBed.createComponent(EditorComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
    const promise = new Promise((resolve, reject) => {
      setTimeout(() => resolve(), 2);
    });
    await promise;
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('setting the component\'s _state attribute should change its state', () => {
    component['map'].mapViewReady.then(
      () => {
        component.state = 'navigation';
        expect(component['map'].navigationEnabled).toBe(true);
        expect(component.basemapVisible).toBe(true);
        expect(component['mainMenuModal'].open).toBe(true);

        // Switching to 'edition' mode when the component's map scale is too large should
        // make the component switch back to 'navigation'.
        component['map'].mapView.scale = 10000;
        component.state = 'edition';
        expect(component.state).toBe('navigation');

        component['map'].mapView.scale = 5000;
        component.state = 'edition';
        expect(component.state).toBe('edition');
        expect(component['map'].navigationEnabled).toBe(false);
      }
    );
  });

  it('setting the component\'s _basemapVisible attribute should change the component\'s map\'s basemap visibility', () => {
    component['map'].mapViewReady.then(
      () => {
        component.basemapVisible = false;
        expect(component['map'].basemapHidden).toBe(true);
        component.basemapVisible = true;
        expect(component['map'].basemapHidden).toBe(false);
      }
    );
  });

  it('setting the component\'s _topographyVisible attribute should change the component\'s map\'s topographyLayer visibility', () => {
    component['map'].mapViewReady.then(
      () => {
        component.topographyVisible = false;
        expect(component.topographyVisible).toBe(false);
        expect(component['map'].topographyHidden).toBe(true);
        component.topographyVisible = true;
        expect(component.topographyVisible).toBe(true);
        expect(component['map'].topographyHidden).toBe(false);
      }
    );
  });

  it('setting the component\'s _drawingsVisible attribute should change the component\'s map\'s drawingsLayer visibility', () => {
    component['map'].mapViewReady.then(
      () => {
        component.drawingsVisible = false;
        expect(component.drawingsVisible).toBe(false);
        expect(component['map'].drawingsHidden).toBe(true);
        component.drawingsVisible = true;
        expect(component.drawingsVisible).toBe(true);
        expect(component['map'].drawingsHidden).toBe(false);
      }
    );
  });

  it('setting the component\'s _visibleTopographicCategory attribute should change its value', () => {
    component['map'].mapViewReady.then(
      () => {
        component.visibleTopographicCategory = 'roads';
        expect(component.visibleTopographicCategory).toBe('roads');
        component.visibleTopographicCategory = 'city';
        expect(component.visibleTopographicCategory).toBe('city');
      }
    );
  });

  it('#openMainMenu should open the component\'s mainMenuModal', () => {
    component.openMainMenu();
    expect(component['mainMenuModal'].open).toBe(true);
  });

  it('#showNavigationtionHelp should open the component\'s navigationHelpModal', () => {
    component.showNavigationHelp();
    expect(component['navigationHelpModal'].open).toBe(true);
  });

  it('#showEditiontionHelp should open the component\'s navigationHelpModal', () => {
    component.showEditionHelp();
    expect(component['editionHelpModal'].open).toBe(true);
  });

  it('#editDrawings should put the component into DrawingMode.EDITING mode', () => {
    component.editDrawings();
    expect(component.drawingMode).toBe(DrawingMode.EDITING);
  });
});
