import * as geometry2d from './geometry2d';

describe('geometry2d', () => {

  it('#clone should create a clone of a Vector2d with the same coordinates', () => {
    const vector: geometry2d.Vector2d = {x: 1, y: 1};
    expect(geometry2d.clone(vector)).toEqual(vector);
  });

  it('#norm should return 0 for a Vector2d with (0, 0) coordinates', () => {
    expect(geometry2d.norm({x: 0, y: 0} as geometry2d.Vector2d)).toBe(0);
  });

  it('#norm should return the euclidean norm of a Vector2d', () => {
    const vector: geometry2d.Vector2d = {x: 1, y: 1};
    const norm = Math.sqrt(vector.x * vector.x + vector.y * vector.y);
    expect(geometry2d.norm(vector)).toBe(norm);
  });

  it('#normal should return the unit normal vector to a Vector2d', () => {
    const vector: geometry2d.Vector2d = {x: 1, y: 1};
    const norm = Math.sqrt(vector.x * vector.x + vector.y * vector.y);
    const unitNormal: geometry2d.Vector2d = {x: -vector.y / norm, y: vector.x / norm};
    expect(geometry2d.normal(vector)).toEqual(unitNormal);
  });

  it('#add should return the result of the addition of two Vector2d', () => {
    const vector1: geometry2d.Vector2d = {x: 1, y: 2};
    const vector2: geometry2d.Vector2d = {x: 2, y: 2};
    const addition: geometry2d.Vector2d = {x: vector1.x + vector2.x, y: vector1.y + vector2.y};
    expect(geometry2d.add(vector1, vector2)).toEqual(addition);
  });

  it('#subtract should return the result of the subtraction of a Vector2d from another', () => {
    const vector1: geometry2d.Vector2d = {x: 2, y: 2};
    const vector2: geometry2d.Vector2d = {x: 1, y: 1};
    const subtraction: geometry2d.Vector2d = {x: vector1.x - vector2.x, y: vector1.y - vector2.y};
    expect(geometry2d.subtract(vector1, vector2)).toEqual(subtraction);
  });

  it('#crossProduct should return the result the cross product between two Vector2d', () => {
    const vector1: geometry2d.Vector2d = {x: 2, y: 3};
    const vector2: geometry2d.Vector2d = {x: 3, y: 4};
    const result = vector1.x * vector2.y - vector1.y * vector2.x;
    expect(geometry2d.crossProduct(vector1, vector2)).toEqual(result);
  });

  it('#scalarMultiplication shoudl return the result of the component-wise multiplication of a Vector2d by a scalar', () => {
    const vector: geometry2d.Vector2d = {x: 1, y: 1};
    const scalar = 3;
    const result: geometry2d.Vector2d = {x: vector.x * scalar, y: vector.y * scalar};
    expect(geometry2d.scalarMultiplication(vector, scalar)).toEqual(result);
  });

  it('#scalarDivision should return the result of the component-wise division of a Vector2d by a scalar', () => {
    const vector: geometry2d.Vector2d = {x: 4, y: 4};
    const scalar = 2;
    const result: geometry2d.Vector2d = {x: vector.x / scalar, y: vector.y / scalar};
    expect(geometry2d.scalarDivision(vector, scalar)).toEqual(result);
  });

  it('#vectorToArray should return an array containing the components of a Vector2d', () => {
    const vector: geometry2d.Vector2d = {x: 1, y: 2};
    expect(geometry2d.vectorToArray(vector)).toEqual([1, 2]);
  });

  it('#arrayToVector should return a Vector2d with the first element of an input array as x and the second as y', () => {
    expect(geometry2d.arrayToVector([1, 2])).toEqual({x: 1, y: 2} as geometry2d.Vector2d);
  });
});
