/**
 * Default basemap to use for maps in the application.
 */
export const defaultBasemap = 'osm';

/**
 * Initial extent for maps in the application. Covers Switzerland.
 */
export const initialExtent = {
    xmin: 780000.0,
    ymin: 5720000.0,
    xmax: 1105000.0,
    ymax: 6100000.0,
    spatialReference: {
        wkid: 102100
    }
} as __esri.Extent;

/**
 * The maximum scale for the map to go to edition mode in the application.
 */
export const maxScaleForEdition = 9027.977411;

/**
 * The width to use in mm for maps in the final A3 print template.
 */
export const printWidthMm = 360;

/**
 * The height to use in mm for maps in the final A3 print template.
 */
export const printHeightMm = 245;

/**
 * The size of the border to use in mm for maps in the final A3 print template.
 */
export const printBorderMm = 2;

/**
 * The dpi to use for printing maps.
 */
export const dpi = 96;

/**
 * Multiplier to convert millimeters to inches.
 */
export const mmToInchMultiplier = 0.0393701;

/**
 * The default aspect ratio (width / height) for maps.
 */
export const mapsAspectRatio = printWidthMm / printHeightMm;
