import { TestBed } from '@angular/core/testing';

import { MapsDatabaseService } from './maps-database.service';
import { HttpClientTestingModule, HttpTestingController } from '@angular/common/http/testing';
import { ABAMap, EsriMap } from './utils';
import { mapServerUrl } from 'src/config/urls';
import { loadModules } from 'esri-loader';

describe('MapsDatabaseService', () => {
  let service: MapsDatabaseService;
  let httpTestingController: HttpTestingController;

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [
        HttpClientTestingModule
      ]
    });
    service = TestBed.get(MapsDatabaseService);
    httpTestingController = TestBed.get(HttpTestingController);
  });

  it('should be created', () => {
    expect(service).toBeTruthy();
  });

  it('#getMapsList should return a list of the maps saved on the maps DB server', () => {
    const expectedResults: ABAMap[] = [
      {
        uid: 1,
        title: 'Onex',
        city: 0,
        creationDate: '05-05-2019'
      },
      {
        uid: 2,
        title: 'Hepia',
        city: 1,
        creationDate: '06-05-2019'
      }
    ];

    const resultsPromise = service.getMapsList();

    const req = httpTestingController.expectOne(`${mapServerUrl}/maps/`);
    expect(req.request.method).toEqual('GET');
    req.flush(expectedResults);

    resultsPromise.then(
      (results) => expect(results).toEqual(expectedResults)
    );
  });

  it('#getMap should return the map associated to some specific id on the maps DB server', () => {
    const expectedResult: ABAMap = {
      uid: 1,
      title: 'Onex',
      city: 0,
      creationDate: '05-05-2019'
    };

    const resultPromise = service.getMap(1);

    const req = httpTestingController.expectOne(`${mapServerUrl}/maps/1`);
    expect(req.request.method).toEqual('GET');
    req.flush(expectedResult);

    resultPromise.then(
      (result) => expect(result).toEqual(expectedResult)
    );
  });

  it('#saveMap should post a map to the maps DB server, and return the new id of the saved map', async () => {
    const [
      Extent,
      Graphic
    ] = await loadModules([
      'esri/geometry/Extent',
      'esri/Graphic'
    ]);

    const map: EsriMap = {
      title: 'Versoix',
      city: 1,
      height: 300,
      width: 600,
      extent: new Extent(),
      graphics: [
        new Graphic()
      ]
    };

    const resultPromise = service.saveMap(map);
    const expectedResult = { id: 1 };

    const req = httpTestingController.expectOne(`${mapServerUrl}`);
    expect(req.request.method).toEqual('POST');
    req.flush(expectedResult);

    resultPromise.then(
      (result) => expect(result).toEqual(expectedResult)
    );
  });
});
