import { getAllTopographyTypes, TopographyTypeName } from "./utils";
import { linesImgUrl, dotImgUrl } from 'src/config/urls';

describe('Topography utils', () => {
  it('#getAllTopographyTypes should return the list of all topography types in the application', async () => {
    const topographyTypes = await getAllTopographyTypes();

    expect(topographyTypes.length).toBe(4);
    expect(topographyTypes[0].name).toBe(TopographyTypeName.BUILDING);
    expect(topographyTypes[0].topographySubTypes).toEqual(['batiment']);
    expect((topographyTypes[0].symbol as __esri.PictureFillSymbol).url).toEqual(linesImgUrl);

    expect(topographyTypes[1].name).toBe(TopographyTypeName.HARD);
    expect(topographyTypes[1].topographySubTypes).toEqual([
      'ilot',
      'trottoir',
      'autre_revetement_dur',
      'rocher',
      'place_aviation'
    ]);
    expect((topographyTypes[1].symbol as __esri.SimpleFillSymbol).color.toHex()).toEqual('#000000');

    expect(topographyTypes[2].name).toBe(TopographyTypeName.LINEAR);
    expect(topographyTypes[2].topographySubTypes).toEqual([
      'route_chemin',
      'chemin_de_fer',
    ]);
    expect((topographyTypes[2].symbol as __esri.SimpleFillSymbol).color.toHex()).toEqual('#000000');

    expect(topographyTypes[3].name).toBe(TopographyTypeName.WATER);
    expect(topographyTypes[3].topographySubTypes).toEqual([
      'eau_stagnante',
      'bassin',
      'cours_eau',
      'fontaine',
    ]);
    expect((topographyTypes[3].symbol as __esri.PictureFillSymbol).url).toEqual(dotImgUrl);
  });
});