/**
 * The interface for coordinates returned by the Geo Admin API.
 */
export interface GeoAdminCoordinates {
  type: string;
  coordinates: number[];
}

/**
 * The interface for the addresses returned by the GeoAdmin API.
 */
export interface Address {
  layerBodId: string;
  geometry: {
    spatialReference: {
      wkid: number;
    },
    x: number;
    y: number;
  };
  attributes: {
    deinr: string;
    strname1: string;
    gdename: string;
  };
}

/**
 * The interface for the water bodies returned by the Geo Admin API.
 */
export interface Waterbody {
  layerBodId: string;
  geometry: {
    paths: number[][][];
    spatialReference: number;
  };
  attributes: {
    name: string;
    label: string;
  };
}

/**
 * The interface for points returned by the Geo Admin API.
 */
export interface GeoAdminPoint {
  attrs: {
    origin: string;
    lat: number;
    lon: number;
    x: number;
    y: number;
  };
}

/**
 * Compute the squared euclidean distance between two points.
 *
 * @param pointA A point with x, y coordinates for which the distance must be computed.
 * @param pointB A second point with x, y coordinates for which the distance must be computed.
 *
 * @returns The squared euclidean distance between points A and B.
 */
export function squaredEuclideanDistance(pointA: {x: number, y: number}, pointB: {x: number, y: number}): number {
  return Math.pow(pointA.x - pointB.x, 2) + Math.pow(pointA.y - pointB.y, 2);
}

/**
 * The possible directions to locate a point on a map
 * (to go from one point to another).
 */
export enum Direction {
  UP = 'up',
  DOWN = 'down',
  LEFT = 'left',
  RIGHT = 'right',
  UP_LEFT = 'up-left',
  UP_RIGHT = 'up-right',
  DOWN_LEFT = 'down-left',
  DOWN_RIGHT = 'down-right',
  CENTER = 'center'
}

/**
 * The interface for directions from a point to another on a map.
 */
export interface MapDirections {
  reached: boolean;
  direction?: Direction;
  distance?: number;
  unit?: 'meters' | 'kilometers';
}

/**
 * The number of meters below which it is considered that a point has been reached on a map.
 */
export const metersPrecision = 10;
