import { TestBed } from '@angular/core/testing';

import { SpeechProcessingService } from './speech-processing.service';
import { TranslateModule } from '@ngx-translate/core';
import { VoiceCommand } from './utils';
import { WebSpeechProvider, SpeechProvider } from './speech-providers';

describe('SpeechProcessingService', () => {
  let service: SpeechProcessingService;
  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [
        TranslateModule.forRoot()
      ]
    });
    service = TestBed.get(SpeechProcessingService);
  });

  it('should be created', () => {
    expect(service).toBeTruthy();
  });

  it('#speechRecognitionSupported should return a boolean indicating if speech recognition can be used in the selected browser', () => {
    const speechRecognitionSupported = service.speechRecognitionSupported();
    expect(speechRecognitionSupported).toBe(true);
  });

  it('#addCommand should add a VoiceCommand to service\'s provider\'s commands', () => {
    const command: VoiceCommand = {
      commands: ['cmd'],
      callback: () => {}
    };
    service.addCommand(command);
    const provider: {[key: string]: any} = service['speechProvider'];
    expect(provider['voiceCommands'].length).toBe(1);
  });

  it('#removeAllCommands should remove all commands from the service\'s provider commands list', () => {
    const command: VoiceCommand = {
      commands: ['cmd'],
      callback: () => {}
    };
    service.addCommand(command);
    service.removeAllCommands();
    const provider: {[key: string]: any} = service['speechProvider'];
    expect(provider['voiceCommands'].length).toBe(0);
  });
});
