/**
 * The languages available in the application.
 */
export enum Language {
  ENGLISH = 'english',
  FRENCH = 'french'
}

/**
 * The identifiers of the languages available in the application.
 */
export const languageIds: {[lang in Language]: string} = {
  [Language.ENGLISH]: 'en-GB',
  [Language.FRENCH]: 'fr-FR'
};

/**
 * The languages associated to the TranslateService language identifiers.
 */
export const translateLanguages: {[key: string]: Language} = {
  en: Language.ENGLISH,
  fr: Language.FRENCH
};

/**
 * The TranslateService language identifiers associated to the application's languages.
 */
export const languagesTranslate: {[Language.ENGLISH]: string, [Language.FRENCH]: string} = {
  [Language.ENGLISH]: 'en',
  [Language.FRENCH]: 'fr'
};

/**
 * The languages recognised by speech recognition.
 */
export const recognisedLanguages: {[key: string]: Language } = {
  english: Language.ENGLISH,
  anglais: Language.ENGLISH,
  francais: Language.FRENCH,
  français: Language.FRENCH,
  french: Language.FRENCH
};

/**
 * The interface for speech recognition voice commands:
 * - 'commands' indicates the text of the different commands to be recognised in
 *   order to perform a specific action;
 * - 'callback' is the function to execute when a command has been recognised.
 */
export interface VoiceCommand {
  commands: string[];
  callback: (param?: string) => void;
}
