import { Injectable } from '@angular/core';
import { TransportProvider, SwissTransportsProvider } from './transport-providers';
import { HttpClient } from '@angular/common/http';
import { Station } from './utils';

@Injectable({
  providedIn: 'root'
})
export class TransportService {

  private transportProvider: TransportProvider;

  constructor(private http: HttpClient) {
    this.transportProvider = new SwissTransportsProvider(this.http);
  }

  /**
   * Get the nearest bus or tram station for a point on a map.
   *
   * @param point An Esri Point with WGS84 coordinates for which the nearest station must be found.
   *
   * @returns A list of Stations near the input point.
   */
  getNearestBusStation(point: __esri.Point): Promise<Station | undefined> {
    return this.transportProvider.getNearestBusStation(point);
  }

  /**
   * Search the nearest station serving a specific line.
   *
   * @param point The Esri Point with WGS84 coordinates near which stations serving a
   * given line must be searched.
   * @param line The name of the line to search for in nearby stations.
   *
   * @returns The nearest station serving the input line.
   */
  getNearestStationByLine(point: __esri.Point, line: string): Promise<Station | undefined> {
    return this.transportProvider.getNearestStationByLine(point, line);
  }

  /**
   * Get the nearest train station to a point on a map.
   *
   * @param point An Esri Point with WGS84 coordinates near which stations must be searched.
   *
   * @returns The nearest station to the input point.
   */
  getNearestTrainStation(point: __esri.Point): Promise<Station | undefined> {
    return this.transportProvider.getNearestTrainStation(point);
  }
}
