import { environment } from '../environments/environment';

/**
 * The URL of the server where the map are saved.
 */
export const mapServerUrl = environment.mapServerUrl;

/**
 * The URL of the application's ArcGIS server.
 */
const arcgisServerUrl = environment.arcgisServerUrl;

/**
 * The URL to retrieve information about a given TopographyType on the application's ArcGIS server.
 */
export const topographyTypesUrl = `${arcgisServerUrl}/audiotactile/audiotactile/FeatureServer/3`;

/**
 * The URL of the proxy for the ArcGIS server.
 */
const topographyProxyUrl = environment.proxyUrl;

/**
 * The proxy rule to apply for all interactions with the application's ArcGIS server.
 */
export const topographyProxyRule: __esri.urlUtilsAddProxyRuleRule = {
  urlPrefix: topographyTypesUrl,
  proxyUrl: topographyProxyUrl,
};

/**
 * Path to the lines.png image.
 */
export const linesImgUrl = 'assets/lines.png';

/**
 * Path to the dot.png image.
 */
export const dotImgUrl = 'assets/dot.png';

/**
 * The URL of the OpenData.ch API to access info about bus stations in Switzerland.
 */
export const busStationsSearchUrl = 'https://transport.opendata.ch/v1/';

/**
 * The URL of the Geo Admin API to access info about train stations in Switzerland.
 */
export const trainStationsSearchUrl = 'https://api3.geo.admin.ch/rest/services/api/MapServer/identify?mapExtent=0,0,300,300&imageDisplay=300,300,300&layers=all:ch.bav.haltestellen-oev&geometryType=esriGeometryPoint&geometry=';

/**
 * The URL of the REST API to transform coordinates from WGS84 to LV03.
 */
export const WGS84ToLV03Url = 'https://geodesy.geo.admin.ch/reframe/wgs84tolv03';

/**
 * The URL of the REST API to transform coordinates from LV03 to WGS84.
 */
export const LV03ToWGS84Url = 'https://geodesy.geo.admin.ch/reframe/lv03towgs84';

/**
 * The URL of the REST API to get the address of a point in Switzerland.
 */
export const addressSearchUrl = 'https://api3.geo.admin.ch/rest/services/api/MapServer/identify?mapExtent=0,0,300,300&imageDisplay=300,300,300&layers=all:ch.bfs.gebaeude_wohnungs_register&geometryType=esriGeometryPoint&geometry=';

/**
 * The URL of the REST API to get the nearest water body to a point in Switzerland.
 */
export const waterbodySearchUrl = 'https://api3.geo.admin.ch/rest/services/api/MapServer/identify?mapExtent=0,0,300,300&imageDisplay=300,300,300&layers=all:ch.swisstopo.vec200-hydrography&geometryType=esriGeometryPoint&geometry=';

/**
 * The URL of the REST API to find the coordinates of addresses in Switzerland.
 */
export const pointSearchUrl = 'https://api3.geo.admin.ch/rest/services/api/SearchServer?type=locations&searchText=';
